MOSViz: MOS Visualization Tool
==============================

MOSViz was a quick-look analysis and visualization tool for multi-object
spectroscopy (MOS).

For documentation see https://mosviz.readthedocs.io/en/latest/

Current Status
--------------

Please note that this version of MOSViz is **no longer being actively supported
or maintained**. The functionality of MOSViz is now available and being actively
developed as part of `Jdaviz <https://github.com/spacetelescope/jdaviz>`_.

If you must use legacy MOSViz, please try v0.3.1 in Python 3.6.

License
-------

This project is Copyright (c) JDADF Developers and licensed under the terms of
the BSD 3-Clause license. See the licenses folder for more information.
